@@ -1,28 +1,28 @@
-'''Examine memory views/bytes.'''
+'''Examine memory views/bytes pretty printing it.'''
 
-__version__ = "0.0.1"
+__version__ = "0.0.5"
 
 _author = 'Di Paola Martin'
-_license = 'GNU GPLv3'
+_license = 'GNU LGPLv3'
 _url = 'https://github.com/bad-address/xview'
 
 _license_disclaimer = r'''Copyright (C) {author} - {url}
 
 This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
+it under the terms of the GNU Lesser General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+GNU Lesser General Public License for more details.
 
-You should have received a copy of the GNU General Public License
+You should have received a copy of the GNU Lesser General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 '''
 
 try:
-    from .xview import examine, Ex, Formatter, display
+    from .xview import Ex, Formatter, display, hexdump
 except (SystemError, ImportError):
     pass  # this happens when importing from setup.py
